<?php 
/**
 * @package Wapple_Architect
 * @author Rich Gubby
 * @version 1.1.1
 */
/*
Plugin Name: Wapple Architect
Plugin URI: http://mobilewebjunkie.com/wordpress-mobile-plugin-install-guide-and-faq/
Description: Mobilizing your wordpress site using Wapple Architect and WAPL. After activating this plugin visit <a href="options-general.php?page=architect.php">the settings page</a> and enter your Wapple Architect Dev Key.
Author: Rich Gubby
Version: 1.1.1
Author URI: http://mobilewebjunkie.com/
*/

/** 
 * Define some defaults - shouldn't need to change these
 */
// Width of images on the homepage
define('ARCHITECT_HOME_IMAGESCALE', 50);
// Quality of images on the homepage
define('ARCHITECT_HOME_IMAGEQUALITY', 95);
// Width of images on post pages
define('ARCHITECT_SINGLE_IMAGESCALE', 50);
// Quality of images on post pages
define('ARCHITECT_SINGLE_IMAGEQUALITY', 95);
// Width of images on designated pages
define('ARCHITECT_PAGE_IMAGESCALE', 50);
// Quality of images on designated pages
define('ARCHITECT_PAGE_IMAGEQUALITY', 95);
// Length of chars in post before a new page
define('ARCHITECT_SINGLE_PAGINGLENGTH', 2000);

/**
 * Debug purposes only - you shouldn't need to change these
 */ 
// Define whether a SOAP call is to be made - won't work without it!
define('ARCHITECT_DO_SOAP', true);
// Force the mobile check to always return true
define('ARCHITECT_FORCE_MOBILE', false);
// Turn a bit more debug on than is normal
define('ARCHITECT_DEBUG', false);

if(ARCHITECT_DEBUG)
{
	error_reporting(E_ALL);
	ini_set('display_errors', true);
}

if ( !defined('WP_CONTENT_DIR') )
	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down

if ( !defined('WP_PLUGIN_DIR') )
	define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash

if ( !defined('WP_CONTENT_URL') )
	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
	
if ( !defined('WP_PLUGIN_URL') )
	define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
	
/**
 * Main device detection kick off function
 * - Sets up a few global variables that we're going to use later and initiates a check for mobile.
 * - If the check for mobile comes back true, amend the path to the theme
 * @return void
 */
function deviceDetection()
{
	// Only do this if we're on a non-admin page (for now!)
	if(!is_admin())
	{
		// Setup a global SOAP client so we can use the same one in the theme
		global $waplSoapClient;
		// Setup global headers so we don't have to get them twice
		global $waplHeaders;
		
		// Create the SOAP client
		$waplSoapClient = __getSoapClient();
		// Get device / browser header information 
		$waplHeaders = __getHeaders();
		
		// If __testForMobile() comes back true, amend template path
		if(__testForMobile())
		{
			// Load the correct file depending on the URL (copied from template-loader.php)
			$template = __templateLoader();
			
			$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.$template;
			
			if(file_exists($file))
			{
				include($file);
				exit(0);
			}
		}
	}
}

/**
 * Work out which theme file to use
 * @return string
 */
function __templateLoader()
{
	if ( is_404()) {
		return '404.php';
	} else if ( is_search()) {
		return 'search.php';
	} else if ( is_home()) {
		return 'index.php';
	} else if ( is_single()) {
		return 'single.php';
	} else if ( is_page()) {
		return 'page.php';
	} else if ( is_archive()) {
		return 'archive.php';
	} else if (file_exists(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'index.php' )) {
		return 'index.php';
	}
}

/**
 * Perform a device detection check
 * @return boolean
 */
function __testForMobile()
{
	global $waplSoapClient;
	global $waplHeaders;
	
	// If we've defined ARCHITECT_DO_SOAP, just return the value of ARCHITECT_FORCE_MOBILE
	if(!ARCHITECT_DO_SOAP)
	{
		return ARCHITECT_FORCE_MOBILE;
	}
	
	if(!get_option('architect_devkey'))
	{
		return false;
	}
	
	// Check for existence of a cookie
	if(isset($_COOKIE['isMobile']))
	{
		return $_COOKIE['isMobile'];
	} else
	{
		// Test for mobile
		$params = array(
			'devKey' => get_option('architect_devkey'),
			'deviceHeaders' => $waplHeaders
		);

		if(!is_object($waplSoapClient))
		{
			// We don't have a SOAP client
			return false;
		}
		$result = $waplSoapClient->isMobileDevice($params);
		if(is_soap_fault($result))
		{
			// There is a SOAP error! probably a dev key error
			return false;
		}  else
		{
			if($result)
			{
				// Set a cookie to remember the outcome!
				setcookie('isMobile', true, time()+3600);
				return true;
			} else
			{
				setcookie('isMobile', false, time()+3600);
				return false;
			}
		}
	}
}

/**
 * Get a SOAP client
 * @return mixed
 */
function __getSoapClient()
{
	if(ARCHITECT_DO_SOAP)
	{
		return new SoapClient('http://webservices.wapple.net/wapl.wsdl', array('exceptions' => 0));
	} else
	{
		return false;
	}	
}

/**
 * Build device header array that SOAP can use
 * @return array
 */
function __getHeaders()
{
	$headers = array();
	foreach($_SERVER as $key => $val)
	{
		$headers[] = array('name' => $key, 'value' => $val);
	}
	return $headers;
}

// Add the deviceDetection function to the template_redirect filter
add_action('template_redirect', 'deviceDetection');
// Add architect options to admin menu
add_action('admin_menu', 'add_architect_options_page');

/**
 * Add architect admin options
 * @return void
 */
function add_architect_options_page()
{
	add_options_page('Wapple Architect Settings', 'Wapple Architect', 8, basename(__FILE__), 'architect_options_page');
}

/**
 * Display architect options and save when requested
 * @return void
 */
function architect_options_page()
{
	echo '<div class="wrap">';
	
	if (isset($_POST['info_update'])) 
	{
		$updateOption = false;
		// Save Dev Key
		if($_POST['architect_devkey'] != get_option('architect_devkey'))
		{
			update_option('architect_devkey', $_POST['architect_devkey']);
			$updateOption = true;
		}
		// Save use header image
		if($_POST['architect_use_headerimage'] != get_option('architect_use_headerimage'))
		{
			update_option('architect_use_headerimage', $_POST['architect_use_headerimage']);
			$updateOption = true;
		}
		// Save actual header image
		if(isset($_FILES['architect_headerimage']))
		{
			$pathToHeader = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'header'.DIRECTORY_SEPARATOR;
			if(move_uploaded_file($_FILES['architect_headerimage']['tmp_name'], $pathToHeader.$_FILES['architect_headerimage']['name']))
			{
				update_option('architect_headerimage', $_FILES['architect_headerimage']['name']);
				$updateOption = true;
			}
		}
		// Save header image BG transparency col
		if($_POST['architect_headerimage_transparency_colour'] != get_option('architect_headerimage_transparency_colour'))
		{
			update_option('architect_headerimage_transparency_colour', $_POST['architect_headerimage_transparency_colour']);
			$updateOption = true;
		}
		// Save use footer image
		if($_POST['architect_use_footerimage'] != get_option('architect_use_footerimage'))
		{
			update_option('architect_use_footerimage', $_POST['architect_use_footerimage']);
			$updateOption = true;
		}
		// Save actual footer image
		if(isset($_FILES['architect_footerimage']))
		{
			$pathToFooter = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'footer'.DIRECTORY_SEPARATOR;
			
			if(move_uploaded_file($_FILES['architect_footerimage']['tmp_name'], $pathToFooter.$_FILES['architect_footerimage']['name']))
			{
				update_option('architect_footerimage', $_FILES['architect_footerimage']['name']);
				$updateOption = true;
			}
		}
		// Save footer image BG transparency col
		if($_POST['architect_footerimage_transparency_colour'] != get_option('architect_footerimage_transparency_colour'))
		{
			update_option('architect_footerimage_transparency_colour', $_POST['architect_footerimage_transparency_colour']);
			$updateOption = true;
		}
		// Save show menu at top
		if($_POST['architect_showmenuattop'] != get_option('architect_showmenuattop'))
		{
			update_option('architect_showmenuattop', $_POST['architect_showmenuattop']);
			$updateOption = true;
		}
		// Save show menu at bottom
		if($_POST['architect_showmenuatbottom'] != get_option('architect_showmenuatbottom'))
		{
			update_option('architect_showmenuatbottom', $_POST['architect_showmenuatbottom']);
			$updateOption = true;
		}
		// Save show excerpt on home page
		if($_POST['architect_home_showexcerpt'] != get_option('architect_home_showexcerpt'))
		{
			update_option('architect_home_showexcerpt', $_POST['architect_home_showexcerpt']);
			$updateOption = true;
		}
		// Save home page image scale
		if($_POST['architect_home_imagescale'] != get_option('architect_home_imagescale'))
		{
			update_option('architect_home_imagescale', $_POST['architect_home_imagescale']);
			$updateOption = true;
		}
		// Save home page image quality
		if($_POST['architect_home_imagequality'] != get_option('architect_home_imagequality'))
		{
			update_option('architect_home_imagequality', $_POST['architect_home_imagequality']);
			$updateOption = true;
		}
		// Save post do paging
		if($_POST['architect_single_dopaging'] != get_option('architect_single_dopaging'))
		{
			update_option('architect_single_dopaging', $_POST['architect_single_dopaging']);
			$updateOption = true;
		}
		// Save post paging length
		if($_POST['architect_single_paginglength'] != get_option('architect_single_paginglength'))
		{
			update_option('architect_single_paginglength', $_POST['architect_single_paginglength']);
			$updateOption = true;
		}
		// Save show post next link
		if($_POST['architect_single_shownext'] != get_option('architect_single_shownext'))
		{
			update_option('architect_single_shownext', $_POST['architect_single_shownext']);
			$updateOption = true;
		}
		// Save post image scale
		if($_POST['architect_single_imagescale'] != get_option('architect_single_imagescale'))
		{
			update_option('architect_single_imagescale', $_POST['architect_single_imagescale']);
			$updateOption = true;
		}
		// Save post image quality
		if($_POST['architect_single_imagequality'] != get_option('architect_single_imagequality'))
		{
			update_option('architect_single_imagequality', $_POST['architect_single_imagequality']);
			$updateOption = true;
		}
		// Save post response format
		if($_POST['architect_single_responseformat'] != get_option('architect_single_responseformat'))
		{
			update_option('architect_single_responseformat', $_POST['architect_single_responseformat']);
			$updateOption = true;
		}
		// Save allow post comments
		if($_POST['architect_single_allowcomments'] != get_option('architect_single_allowcomments'))
		{
			update_option('architect_single_allowcomments', $_POST['architect_single_allowcomments']);
			$updateOption = true;
		}
		// Save page image scale
		if($_POST['architect_page_imagescale'] != get_option('architect_page_imagescale'))
		{
			update_option('architect_page_imagescale', $_POST['architect_page_imagescale']);
			$updateOption = true;
		}
		// Save page image quality
		if($_POST['architect_page_imagequality'] != get_option('architect_page_imagequality'))
		{
			update_option('architect_page_imagequality', $_POST['architect_page_imagequality']);
			$updateOption = true;
		}
		// Save home show search
		if($_POST['architect_home_showsearch'] != get_option('architect_home_showsearch'))
		{
			update_option('architect_home_showsearch', $_POST['architect_home_showsearch']);
			$updateOption = true;
		}
		// Save search page show tags
		if($_POST['architect_search_showtags'] != get_option('architect_search_showtags'))
		{
			update_option('architect_search_showtags', $_POST['architect_search_showtags']);
			$updateOption = true;
		}
		// Save search page show categories
		if($_POST['architect_search_showcategories'] != get_option('architect_search_showcategories'))
		{
			update_option('architect_search_showcategories', $_POST['architect_search_showcategories']);
			$updateOption = true;
		}
		
		// Save Mobile stylesheet
		$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'style.css';
		$stylesheet = file_get_contents($file);
		
		if(stripslashes($_POST['architect_stylesheet']) != $stylesheet)
		{
			if(file_put_contents($file, stripslashes($_POST['architect_stylesheet'])))
			{
				$updateOption = true;
			}
		}
		
		// Save custom stylesheet
		$custom_file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'custom_style.css';
		$custom_stylesheet = file_get_contents($custom_file);
		
		if(stripslashes($_POST['architect_custom_stylesheet']) != $custom_stylesheet)
		{
			if(file_put_contents($custom_file, stripslashes($_POST['architect_custom_stylesheet'])))
			{
				$updateOption = true;
			}
		}
		
		if($updateOption)
		{
			echo "<div class='updated fade'><p><strong>Wapple Architect settings saved.</strong></p></div>";
		}
	}
	
	if(get_option('architect_devkey') == '' OR !get_option('architect_devkey'))
	{
		echo '<div class="updated" style="background:#F24318;color:#000;border-color:#B23112;"><p><strong>You haven\'t saved your free Wapple Architect Dev Key, get one from here: <a href="http://wapple.net/register/free-developer-program-for-coding-mobile-web.htm" style="color:#000;">http://wapple.net/register/free-developer-program-for-coding-mobile-web.htm</a></strong></p></div>';
	}
	
	echo '<form method="post" action="options-general.php?page=architect.php" enctype="multipart/form-data">';
	echo architect_admin_header('2', 'Wapple Architect Settings');
	
	echo '<p><em>Wapple Architect WordPress plugin is brought to you by Rich Gubby - <a href="http://mobilewebjunkie.com">http://mobilewebjunkie.com</a></em></p>';

	echo architect_table_start();
	echo architect_admin_header('3', 'Basic Settings');	
	
	// Dev Key
	echo architect_admin_option('input', array('label' => 'Wapple Architect Dev Key', 'name' => 'architect_devkey', 'value' => get_option('architect_devkey')));
	
	// Use a mobile header image
	echo architect_admin_option('select', array('label' => 'Use mobile header image', 'name' => 'architect_use_headerimage', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_use_headerimage')));
	
	// Upload a mobile header image	
	echo architect_admin_option('file', array('label' => 'Mobile site header image', 'name' => 'architect_headerimage'));
	
	// Transparency colour for header image
	echo architect_admin_option('input', array('label' => 'Header BG transparency colour', 'size' => 6, 'name' => 'architect_headerimage_transparency_colour', 'value' => get_option('architect_headerimage_transparency_colour'), 'before' => '#'));
	
	// Show mobile header image preview
	if(get_option('architect_headerimage'))
	{
		echo architect_admin_option('image', array('label' => 'Mobile site header image preview', 'alt' => 'Mobile Header Image', 'src' => '/wp-content/plugins/'.get_wapl_plugin_base().'/theme/images/header/'.get_option('architect_headerimage')));
	}
	
	// Use a mobile footer image
	echo architect_admin_option('select', array('label' => 'Use mobile footer image', 'name' => 'architect_use_footerimage', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_use_footerimage')));
	
	// Upload a mobile footer image	
	echo architect_admin_option('file', array('label' => 'Mobile site footer image', 'name' => 'architect_footerimage'));
	
	// Transparency colour for footer image
	echo architect_admin_option('input', array('label' => 'Footer BG transparency colour', 'size' => 6, 'name' => 'architect_footerimage_transparency_colour', 'value' => get_option('architect_footerimage_transparency_colour'), 'before' => '#'));
	
	// Show mobile footer image preview
	if(get_option('architect_footerimage'))
	{
		echo architect_admin_option('image', array('label' => 'Mobile site footer image preview', 'alt' => 'Mobile Footer Image', 'src' => '/wp-content/plugins/'.get_wapl_plugin_base().'/theme/images/footer/'.get_option('architect_footerimage')));
	}
	
	// Show menu at top
	echo architect_admin_option('select', array('label' => 'Show menu at top', 'name' => 'architect_showmenuattop', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showmenuattop')));
	
	// Show menu at bottom
	echo architect_admin_option('select', array('label' => 'Show menu at bottom', 'name' => 'architect_showmenuatbottom', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showmenuatbottom')));

	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Home Page Settings');
	
	// Show home page excerpt
	echo architect_admin_option('select', array('label' => 'Show excerpt on homepage', 'name' => 'architect_home_showexcerpt', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_home_showexcerpt')));
	
	// Image scale on home page
	$homepagescale = ARCHITECT_HOME_IMAGESCALE;
	if(get_option('architect_home_imagescale'))
	{
		$homepagescale = get_option('architect_home_imagescale');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image scale on homepage', 'name' => 'architect_home_imagescale', 'value' => $homepagescale, 'after' => '%'));	

	// Image quality on home page
	$homepagequality = ARCHITECT_HOME_IMAGEQUALITY;
	if(get_option('architect_home_imagequality'))
	{
		$homepagequality = get_option('architect_home_imagequality');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image quality on homepage', 'name' => 'architect_home_imagequality', 'value' => $homepagequality, 'after' => '%'));	
	
	// Show search on home page
	echo architect_admin_option('select', array('label' => 'Show search on home page', 'name' => 'architect_home_showsearch', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_home_showsearch')));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Posts Settings');
	
	// Pagination on posts
	echo architect_admin_option('select', array('label' => 'Do pagination', 'name' => 'architect_single_dopaging', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_dopaging')));
		
	// Pagination length
	$singlepagepaginglength = ARCHITECT_SINGLE_PAGINGLENGTH;
	if(get_option('architect_single_paginglength'))
	{
		$singlepagepaginglength = get_option('architect_single_paginglength');
	}
	echo architect_admin_option('input', array('size' => 4, 'label' => 'Post length', 'name' => 'architect_single_paginglength', 'value' => $singlepagepaginglength, 'after' => 'chars'));
	
	// Show next/prev links on posts
	echo architect_admin_option('select', array('label' => 'Show next/previous links', 'name' => 'architect_single_shownext', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_shownext')));
		
	// Image scale on posts
	$singlepagescale = ARCHITECT_SINGLE_IMAGESCALE;
	if(get_option('architect_single_imagescale'))
	{
		$singlepagescale = get_option('architect_single_imagescale');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image scale on post', 'name' => 'architect_single_imagescale', 'value' => $singlepagescale, 'after' => '%'));
	
	// Image quality on posts
	$singlepagequality = ARCHITECT_SINGLE_IMAGEQUALITY;
	if(get_option('architect_single_imagequality'))
	{
		$singlepagequality = get_option('architect_single_imagequality');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image quality on post', 'name' => 'architect_single_imagequality', 'value' => $singlepagequality, 'after' => '%'));
	
	// Responses text
	$options = array(
		'1' => '1 response',
		'2' => '1 response to [post title]',
		'3' => '1 comment',
		'4' => '1 comment to [post title]',
	);
	echo architect_admin_option('select', array('label' => '# responses text', 'name' => 'architect_single_responseformat', 'options' => $options, 'value' => get_option('architect_single_responseformat')));

	// Allow comments on posts
	echo architect_admin_option('select', array('label' => 'Allow comments on posts', 'name' => 'architect_single_allowcomments', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_allowcomments')));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Pages Settings');
	
	// Image scale on pages
	$pagescale = ARCHITECT_PAGE_IMAGESCALE;
	if(get_option('architect_page_imagescale'))
	{
		$pagescale = get_option('architect_page_imagescale');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image scale on page', 'name' => 'architect_page_imagescale', 'value' => $pagescale, 'after' => '%'));

	// Image quality on pages
	$pagequality = ARCHITECT_PAGE_IMAGEQUALITY;
	if(get_option('architect_page_imagequality'))
	{
		$pagequality = get_option('architect_page_imagequality');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image quality on page', 'name' => 'architect_page_imagequality', 'value' => $pagequality, 'after' => '%'));

	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Search Results Settings');
	
	// Show tags on search results
	echo architect_admin_option('select', array('label' => 'Show tags on search results', 'name' => 'architect_search_showtags', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_search_showtags')));
	
	// Show categories on search results
	echo architect_admin_option('select', array('label' => 'Show categories on search results', 'name' => 'architect_search_showcategories', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_search_showcategories')));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Mobile Theme Settings');
	
	// Mobile stylesheet
	echo architect_admin_option('textarea', array('label' => 'Mobile Stylesheet', 'name' => 'architect_stylesheet', 'value' => file_get_contents(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'style.css')));

	// Custom stylesheet
	echo architect_admin_option('textarea', array('label' => 'Custom Mobile Stylesheet', 'name' => 'architect_custom_stylesheet', 'value' => file_get_contents(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'custom_style.css')));
	
	echo '</table>';
	echo '<table class="form-table" cellspacing="2" cellpadding="5" width="100%"><tr><td><p class="submit"><input class="button-primary" type="submit" name="info_update" value="Save Changes" /></p></td></tr></table></form></div>';
}

function architect_add_headerimage()
{
	echo '<input type="file" name="architect_add_headerimage" id="architect_add_headerimage" />';
}

if(!function_exists('get_wapl_plugin_base'))
{
	function get_wapl_plugin_base()
	{
		// Fix non conforming directory separators!
		$opposite = array('/' => '\\', '\\' => '/');
		$base = str_replace($opposite[DIRECTORY_SEPARATOR], DIRECTORY_SEPARATOR, plugin_basename(__FILE__));
		
		$baseExplode = explode(DIRECTORY_SEPARATOR, $base);
		return $baseExplode[0];
	}
}

if(!function_exists('architect_admin_header'))
{
	function architect_admin_header($h, $value)
	{
		return '<tr><td><h'.$h.' style="margin:0;font-size:1.3em;">'.$value.'</h'.$h.'></td></tr>';
	}
}
if(!function_exists('architect_table_start'))
{
	function architect_table_start()
	{
		return '<table class="form-table" cellspacing="2" cellpadding="5" width="100%" style="margin-top:5px;margin-bottom:0px;border:solid 1px #404040;">';
	}
}
if(!function_exists('architect_admin_option'))
{
	function architect_admin_option($type, $options = array())
	{
		$string  = '<tr>';
		$string .= '<th width="30%" valign="top" style="padding-top: 10px;"><label for="'.$options['name'].'">'.$options['label'].': </label></th><td>';
		
		switch($type)
		{
			case 'input' : 
				if(!isset($options['size']))
				{
					$options['size'] = 40;
				}
				if(isset($options['before']) AND $options['before'] != '')
				{
					$string .= $options['before'];
				}
				$string .= '<input size="'.$options['size'].'" type="text" name="'.$options['name'].'" id="'.$options['name'].'" value="'.$options['value'].'" />';
				
				if(isset($options['after']) AND $options['after'] != '')
				{
					$string .= $options['after'];
				}
				break;
			case 'select' :
				$string .= '<select name="'.$options['name'].'">';
				foreach($options['options'] as $key => $val)
				{
					$string .= '<option value="'.$key.'"';
				
					if($key == $options['value'])
					{
						$string .= ' selected="selected"';
					}
					
					$string .= '>'.$val.'</option>';
				}
				$string .= '</select>';
				break;
			case 'file' :
				$string .= '<input type="file" name="'.$options['name'].'" id="'.$options['name'].'" />';
				break;
			case 'image' :
				$string .= '<img src="'.$options['src'].'" alt="'.$options['alt'].'" />';
				break;
			case 'textarea' :
				if(!isset($options['rows']))
				{
					$options['rows'] = 25;
				}
				if(!isset($options['cols']))
				{
					$options['cols'] = 70;
				}
				$string .= '<textarea id="'.$options['name'].'" name="'.$options['name'].'" rows="'.$options['rows'].'" cols="'.$options['cols'].'">'.$options['value'].'</textarea>';
				break;
		}
		
		$string .= '</td></tr>';
		return $string;
	}
}
?>